@@ -43,6 +43,7 @@ from .sqlc import (
     get_task_run_by_id,
     register_executor,
     disconnect_executor,
+    mark_running_tasks_lost,
     batch_update_heartbeat_on_executors,
     update_executor_stats,
     batch_update_heartbeat_log,
@@ -81,6 +82,7 @@ from .sqlc import (
     get_task_run_by_id_sync,
     register_executor_sync,
     disconnect_executor_sync,
+    mark_running_tasks_lost_sync,
     batch_update_heartbeat_on_executors_sync,
     update_executor_stats_sync,
     batch_update_heartbeat_log_sync,
@@ -202,19 +204,16 @@ class SqlcDispatcher(Dispatcher):
             )
 
     def retry_task(self, task_id: UUID, backoff_seconds: int):
-        scheduled_start = None
-        if backoff_seconds > 0:
-            scheduled_start = datetime.now(timezone.utc) + timedelta(
-                seconds=backoff_seconds
-            )
-
+        # TODO: backoff_seconds is not currently supported in the conditionally_retry_task function
+        # The scheduled_start would need to be added to the SQL function signature
+        
         with self.transaction() as conn:
             conditionally_retry_task_sync(
                 conn,
                 conditionally_retry_task.ConditionallyRetryTaskParams(
-                    task_id=task_id,
+                    existing_task_id=task_id,
                     new_task_id=uuid7(),
-                    scheduled_start=scheduled_start,
+                    timeout_seconds=None,  # Use the original timeout from the task
                 ),
             )
 
@@ -435,6 +434,23 @@ class SqlcDispatcher(Dispatcher):
                 ),
             )
 
+    def mark_running_tasks_lost(self, executor_id: UUID):
+        """Mark all running tasks for a specific executor as lost and create retry tasks if needed.
+        
+        This is typically called when an executor is detected as lost/disconnected.
+        Tasks that haven't exceeded max_retries will be automatically re-queued.
+        
+        Args:
+            executor_id: The ID of the executor whose tasks should be marked as lost
+        """
+        with self.transaction() as conn:
+            mark_running_tasks_lost_sync(
+                conn,
+                mark_running_tasks_lost.MarkRunningTasksLostParams(
+                    executor_id=executor_id
+                ),
+            )
+
     def executor_heartbeat(self, executor_ids: list[UUID], timestamp: datetime):
         with self.transaction() as conn:
             batch_update_heartbeat_on_executors_sync(
@@ -559,15 +575,20 @@ class SqlcDispatcher(Dispatcher):
 
     def _create_insert_task_command(self, task: EnqueueTaskRequest) -> str:
         """Create SQL command for inserting a task (used by cron jobs)."""
-        # This is a simplified version - you may need to adjust based on your exact SQL
+        # Use a CTE to generate one UUID7 and use it for id, durable_id, and root_id
+        # Parent ID is always NULL for cron-based tasks
         return f"""
+        WITH new_uuid AS (
+            SELECT uuid7() AS task_id
+        )
         INSERT INTO hyrex_task_run (
             id, durable_id, root_id, parent_id, task_name, args, queue,
             max_retries, priority, timeout_seconds, idempotency_key, status,
             workflow_run_id, workflow_dependencies, attempt_number, queued
-        ) VALUES (
-            '{task.id}'::uuid, '{task.durable_id}'::uuid, '{task.root_id}'::uuid,
-            {f"'{task.parent_id}'::uuid" if task.parent_id else 'NULL'},
+        ) 
+        SELECT 
+            task_id, task_id, task_id,
+            NULL,
             '{task.task_name}', '{json.dumps(task.args)}'::json, '{task.queue}',
             {task.max_retries}, {task.priority},
             {task.timeout_seconds if task.timeout_seconds else 'NULL'},
@@ -576,7 +597,7 @@ class SqlcDispatcher(Dispatcher):
             {f"'{task.workflow_run_id}'::uuid" if task.workflow_run_id else 'NULL'},
             {f"ARRAY{task.workflow_dependencies}::uuid[]" if task.workflow_dependencies else 'NULL'},
             0, CURRENT_TIMESTAMP
-        )
+        FROM new_uuid
         """
 
     def register_workflow(
@@ -630,7 +651,7 @@ class SqlcDispatcher(Dispatcher):
                 ),
             )
 
-            if updated_row and updated_row.status in ("FAILED", "SUCCESS"):
+            if updated_row and updated_row[1] in ("FAILED", "SUCCESS"):
                 return None
 
             # Advance the workflow
@@ -782,7 +803,7 @@ class SqlcDispatcher(Dispatcher):
                         conn, fetch_result.FetchResultParams(task_id=row.id)
                     )
                     if result_row:
-                        result_data = result_row.result
+                        result_data = result_row
 
                 task_run = TaskRun(
                     id=row.id,
@@ -841,7 +862,7 @@ class SqlcDispatcher(Dispatcher):
             result = fetch_result_sync(
                 conn, fetch_result.FetchResultParams(task_id=task_id)
             )
-            return result.result if result else None
+            return result if result else None
 
     def kv_set(self, key: str, value: str) -> None:
         with self.transaction() as conn:
